@@ -1095,7 +1095,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
 
         :default: - No Lambda Insights
 
-        :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights.html
+        :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights-Getting-Started-docker.html
         '''
         result = self._values.get("insights_version")
         return typing.cast(typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion], result)
